<?php
/**
 * @copyright (C) 2021 - 2022 Holger Brandt IT Solutions
 * @license GPL2
*/

if(!defined('ABSPATH')){
    exit;
}

class WADA_Database
{
    const TBL_EVENTS = '#__wada_events';
    const TBL_EVENT_INFOS = '#__wada_event_infos';
    const TBL_EXTENSIONS = '#__wada_extensions';
    const TBL_EVENT_NOTIFICATIONS = '#__wada_event_notifications';
    const TBL_NOTIFICATIONS = '#__wada_notifications';
    const TBL_SENSORS = '#__wada_sensors';
    const TBL_SETTINGS = '#__wada_settings';

    public static function tbl_events(){
        return self::assignDatabasePrefix(self::TBL_EVENTS);
    }
    public static function tbl_event_infos(){
        return self::assignDatabasePrefix(self::TBL_EVENT_INFOS);
    }
    public static function tbl_event_notifications(){
        return self::assignDatabasePrefix(self::TBL_EVENT_NOTIFICATIONS);
    }
    public static function tbl_extensions(){
        return self::assignDatabasePrefix(self::TBL_EXTENSIONS);
    }
    public static function tbl_notifications(){
        return self::assignDatabasePrefix(self::TBL_NOTIFICATIONS);
    }
    public static function tbl_sensors(){
        return self::assignDatabasePrefix(self::TBL_SENSORS);
    }
    public static function tbl_settings(){
        return self::assignDatabasePrefix(self::TBL_SETTINGS);
    }

    public static function assignDatabasePrefix($sql, $placeholder='#__'){
        global $wpdb;
        return str_replace($placeholder, $wpdb->prefix, $sql);
    }

    public static function createIndexIfNotExists($table, $indexName, $cols){
        global $wpdb;
        $indexExists = false;
        $query = 'SHOW INDEXES FROM ' . $table;
        $result = $wpdb->get_results( $query );
        for($i=0; $i < count($result); $i++){
            $currIndex = &$result[$i];
            $currIndexName = $currIndex->Key_name;
            if($currIndexName == $indexName){
                $indexExists = true;
                break;
            }
        }

        if(!$indexExists){

            $query = 'ALTER TABLE ' . $table . ' ADD INDEX ' . $indexName . ' ( ' . $cols[0];
            for($i=1; $i < count($cols); $i++){
                $query .= ', ' . $cols[$i];
            }
            $query .= ')';
            $errorMsg = '';
            try {
                $result = $wpdb->query( $query );
            } catch (Exception $e) {
                $errorMsg = 'Error No: ' . $e->getCode() . ', Message: ' . $e->getMessage();
            }
            if(false === $result){
                //$log->error('Error while creating index ' . $indexName . ' in ' . $table . ', columns: ' . print_r($cols, true) . ', Message: ' . $errorMsg);
                return -1;
            }
            //$log->info('Created index ' . $indexName . ' in ' . $table );
            return 1;
        }
        //$log->info('Index ' . $indexName . ' already in ' . $table );
        return 0;
    }
}
