<?php
/**
 * @copyright (C) 2021 - 2022 Holger Brandt IT Solutions
 * @license GPL2
*/

if(!defined('ABSPATH')){
    exit;
}

class WADA_Model_Stats extends WADA_Model_BaseReadOnly
{
    public function __construct($options = array()){
        parent::__construct($options);
    }

    protected function loadData($options = array()){
        $res = array();
        //WADA_Log::debug('WADA_Model_Stats->loadData with options: '.print_r($options, true));
        if(array_search('general_events', $options) !== false){
            $res['general_events'] = $this->getEventCounts();
        }
        if(array_search('general_sensors', $options) !== false){
            $res['general_sensors'] = $this->getSensorCounts();
        }
        if(array_search('first_event', $options) !== false){
            $res['first_event'] = $this->getFirstEvent();
        }
        $this->_data = $res;
    }

    protected function getFirstEvent(){
        global $wpdb;
        $res = null;
        $sql = 'SELECT * FROM '.WADA_Database::tbl_events().' WHERE occurred_on IN (SELECT MIN(occurred_on) FROM '.WADA_Database::tbl_events().') LIMIT  1';
        $firstEvent = $wpdb->get_row($sql);
        if($firstEvent){
            $res = new stdClass();
            $res->id = $firstEvent->id;
            $res->date_utc = $firstEvent->occurred_on;
            $res->date_wp = WADA_DateUtils::formatUTCasDatetimeForWP($res->date_utc);
        }
        return $res;
    }

    public function getEventCounts(){
        global $wpdb;

        $sql = 'SELECT severity, sum(event_cr) as sev_cr '
            .'FROM ( '
            .'SELECT ev.sensor_id, ev.event_cr, sen.severity '
            .'FROM (SELECT sensor_id, count(*) as event_cr FROM '.WADA_Database::tbl_events().' GROUP BY sensor_id) ev '
            .'LEFT JOIN '.WADA_Database::tbl_sensors().' sen ON (ev.sensor_id = sen.id) '
            .') sev_stats GROUP BY severity';
        $eventCounts = $wpdb->get_results($sql);
        $severitiesOnFile = array_column($eventCounts, 'severity');
        $severityLevels = WADA_Model_Sensor::getSeverityLevels();

        $totalEventCount = 0;
        $severityResult = array();
        foreach($severityLevels AS $severityLevel => $severityName){
            $resultObj = new stdClass();
            $resultObj->severity = $severityLevel;
            $resultObj->name = $severityName;
            $found = array_search($severityLevel, $severitiesOnFile);
            if($found === false){
                $resultObj->count = 0;
            }else{
                $resultObj->count = $eventCounts[$found]->sev_cr;
            }
            $totalEventCount += $resultObj->count;
            $severityResult[] = $resultObj;
        }

        $result = new stdClass();
        $result->totalEvents = $totalEventCount;
        $result->bySeverityLevel = $severityResult;
        //WADA_Log::debug('WADA_Model_Stats->getEventCounts result: '.print_r($result, true));

        return $result;
    }


    public function getSensorCounts(){
        global $wpdb;

        $sql = 'SELECT active, count(*) as sensor_cr FROM '.WADA_Database::tbl_sensors().' GROUP BY active';
        $sensorCounts = $wpdb->get_results($sql);

        $totalSensors = 0;
        $sensorStatusCount = new stdClass();
        $sensorStatusCount->active = 0;
        $sensorStatusCount->inactive = 0;
        foreach($sensorCounts AS $sensorStatus){
            $totalSensors += $sensorStatus->sensor_cr;
            if($sensorStatus->active == 1){
                $sensorStatusCount->active += $sensorStatus->sensor_cr;
            }else{
                $sensorStatusCount->inactive += $sensorStatus->sensor_cr;
            }
        }
        $result = new stdClass();
        $result->totalSensors = $totalSensors;
        $result->bySensorStatus = $sensorStatusCount;
        //WADA_Log::debug('WADA_Model_Stats->getSensorCounts result: '.print_r($result, true));

        return $result;
    }
}