<?php
/**
 * @copyright (C) 2021 - 2022 Holger Brandt IT Solutions
 * @license GPL2
*/

if(!defined('ABSPATH')){
    exit;
}

class WADA_Sensor_Plg_WADA extends WADA_Sensor_Base
{
    public function __construct(){
        parent::__construct(WADA_Sensor_Base::GRP_PLG_WADA);
    }

    public function registerSensor(){
        add_action('wp_admin_audit_sensor_status_change', array($this, 'onSensorStatusChange'), 10, 3);
        add_action('wpadminaudit_sensor_update', array($this, 'onSensorUpdate'), 10, 3);
        add_action('wpadminaudit_settings_update', array($this, 'onSettingsUpdate'), 10, 2);
        //WADA_Log::debug('Active sensors for group '.$this->sensorGroup.': '.print_r($this->activeSensors, true));
    }

    /**
     * @param int $sensorId
     * @param int $newStatus
     * @param int $previousStatus
     */
    public function onSensorStatusChange($sensorId, $newStatus, $previousStatus){
        if(!$this->isActiveSensor(self::EVT_PLG_WADA_SENSOR_UPDATE)) return $this->skipEvent(self::EVT_PLG_WADA_SENSOR_UPDATE);
        WADA_Log::debug('onSensorStatusChange for sensor '.$sensorId.', new status: '.$newStatus.', previous status: '.$previousStatus);
        $infos = array();
        $infos[] = self::getEventInfoElement('active', $newStatus, $previousStatus);
        $eventData = array('infos' => $infos);
        $executingUserId = get_current_user_id();
        $targetObjectId = $sensorId;
        $targetObjectType = self::OBJ_TYPE_PLG_WADA_SENSOR;
        return $this->storeWADAEvent(self::EVT_PLG_WADA_SENSOR_UPDATE, $eventData, $executingUserId, $targetObjectId, $targetObjectType);
    }

    /**
     * @param int $sensorId
     * @param array $sensorAfterUpdate
     * @param array $sensorBeforeUpdate
     */
    public function onSensorUpdate($sensorId, $sensorAfterUpdate, $sensorBeforeUpdate){
        if(!$this->isActiveSensor(self::EVT_PLG_WADA_SENSOR_UPDATE)) return $this->skipEvent(self::EVT_PLG_WADA_SENSOR_UPDATE);
        WADA_Log::debug('onSensorUpdate for sensor '.$sensorId.', sensor now: '.print_r($sensorAfterUpdate, true).', sensor before: '.print_r($sensorBeforeUpdate, true));
        $infos = WADA_CompUtils::getChangedAttributes((object)$sensorBeforeUpdate, (object)$sensorAfterUpdate, array('active', 'severity', 'name', 'description'));
        $eventData = array('infos' => $infos);
        $executingUserId = get_current_user_id();
        $targetObjectId = $sensorId;
        $targetObjectType = self::OBJ_TYPE_PLG_WADA_SENSOR;
        return $this->storeWADAEvent(self::EVT_PLG_WADA_SENSOR_UPDATE, $eventData, $executingUserId, $targetObjectId, $targetObjectType);
    }

    /**
     * @param array $settingsAfterSaving
     * @param array $settingsPriorSaving
     */
    public function onSettingsUpdate($settingsAfterSaving, $settingsPriorSaving){
        if(!$this->isActiveSensor(self::EVT_PLG_WADA_SETTINGS_UPDATE)) return $this->skipEvent(self::EVT_PLG_WADA_SETTINGS_UPDATE);

        WADA_Log::debug('onSettingsUpdate settings now: '.print_r($settingsAfterSaving, true).', settings before: '.print_r($settingsPriorSaving, true));
        $infos = array();
        foreach($settingsPriorSaving AS $settingId => $priorSettingObj){
            if(array_key_exists($settingId, $settingsAfterSaving)){
                if($priorSettingObj->value !== $settingsAfterSaving[$settingId]->value) {
                    $infos[] = array(
                        'info_key' => $priorSettingObj->name,
                        'info_value' => $settingsAfterSaving[$settingId]->value,
                        'prior_value' => $priorSettingObj->value
                    );
                }
            }
        }
        $eventData = array('infos' => $infos);
        $executingUserId = get_current_user_id();
        return $this->storeWADAEvent(self::EVT_PLG_WADA_SETTINGS_UPDATE, $eventData, $executingUserId);
    }

    /**
     * @param int $sensorId
     * @param array $eventData
     * @param int $executingUserId
     * @param int $targetObjectId
     * @param string $targetObjectType
     * @return bool
     */
    protected function storeWADAEvent($sensorId, $eventData = array(), $executingUserId = 0, $targetObjectId = 0, $targetObjectType = null){
        $event = (object)(array_merge($this->getEventDefaults($executingUserId, $targetObjectId, $targetObjectType), $eventData));
        return $this->storeEvent($sensorId, $event);
    }

}