<?php
/**
 * @copyright (C) 2021 - 2022 Holger Brandt IT Solutions
 * @license GPL2
*/

if(!defined('ABSPATH')){
    exit;
}

class WADA_UserUtils
{

    /**
     * @param WP_User $previousUser
     * @param WP_User $currentUser
     * @return array
     */
	public static function getChangedAttributes($previousUser, $currentUser){
		$changedAttributes = array();
		if(($previousUser instanceof WP_User) && ($currentUser instanceof WP_User)) {
            $changedAttributes = array_merge($changedAttributes, self::getChangedTopLevelAttributes($previousUser, $currentUser));
            $changedAttributes = array_merge($changedAttributes, self::getChangedRoles($previousUser, $currentUser));
        }else{
		    WADA_Log::debug('getChangedAttributes No comparison possible');
            WADA_Log::debug('getChangedAttributes previousUser: '.print_r($previousUser, true));
            WADA_Log::debug('getChangedAttributes currentUser: '.print_r($currentUser, true));
        }
		return $changedAttributes;
	}

    /**
     * @return string[]
     */
	public static function getTopLevelAttributes(){
	    return array(
            'user_login', 'user_pass', 'user_nicename', 'user_email', 'user_url',
            'user_registered', 'user_activation_key', 'user_status', 'display_name'
        );
    }

    /**
     * @param WP_User $previousUser
     * @param WP_User $currentUser
     * @return array
     */
	protected static function getChangedTopLevelAttributes($previousUser, $currentUser){
        $attributes2Check = self::getTopLevelAttributes();
        return WADA_CompUtils::getChangedAttributes($previousUser, $currentUser, $attributes2Check);
    }

    /**
     * @param WP_User $previousUser
     * @param WP_User $currentUser
     * @return array
     */
    protected static function getChangedRoles($previousUser, $currentUser){
        $changedRoles = array();

        if($previousUser && property_exists($previousUser, 'roles')
            && $currentUser && property_exists($currentUser, 'roles')){
            sort($previousUser->roles); // sort roles
            sort($currentUser->roles); // sort roles
            $previousRoles = implode(', ', $previousUser->roles);
            $currentRoles = implode(', ', $currentUser->roles);

            if($previousRoles !== $currentRoles){
                $changedRoles[] = array(
                    'info_key' => 'roles',
                    'info_value' => $currentRoles,
                    'prior_value' => $previousRoles
                );
            }
        }

        return $changedRoles;
    }

}
