<?php
/**
 * @copyright (C) 2021 - 2022 Holger Brandt IT Solutions
 * @license GPL2
*/

if(!defined('ABSPATH')){
    exit;
}

class WADA_View_Dashboard extends WADA_View_BaseForm
{
    const VIEW_IDENTIFIER = 'wada-dashboard';
    protected $_stats;

    public function __construct(){
        $options = array('general_events', 'first_event', 'general_sensors');
        $statsModel = new WADA_Model_Stats($options);
        $this->_stats = $statsModel->_data;
        WADA_Log::debug('Dashboard view, stats: '.print_r($this->_stats, true));
    }

    protected function handleFormSubmissions(){
        if(isset($_POST['submit'])){
            check_admin_referer(self::VIEW_IDENTIFIER);
        }
    }

    protected function displayForm(){
        $pluginPath = 'wp-admin-audit';
        $assetsUrl = trailingslashit( plugins_url($pluginPath) );
    ?>
        <div class="wrap">
            <h1><?php _e('Dashboard', 'wp-admin-audit'); ?></h1>
            <div id="wada-welcome-panel" class="wada-welcome-panel wada-dashboard">
                <div class="wada-version"><?php echo WADA_Version::getProductName(true, false); ?></div>
                <div class="wada-welcome-panel-content">
                    <h2><?php _e('Welcome!', 'wp-admin-audit'); ?></h2>
                    <p class="about-description"><?php _e('Here is your overview', 'wp-admin-audit'); ?></p>
                    <div class="wada-welcome-panel-column-container">
                        <div class="wada-welcome-panel-column">
                            <h3><?php _e('Events', 'wp-admin-audit'); ?></h3>
                            <ul>
                                <li><?php
                                    $nrEventsStr = ('<span class="wada-db-stat-cr">' . $this->_stats['general_events']->totalEvents . '</span>');
                                    if(!isset($this->_stats['first_event']) || !$this->_stats['first_event'] || !property_exists($this->_stats['first_event'], 'date_wp')){
                                        echo sprintf(__('%s events', 'wp-admin-audit'), $nrEventsStr);
                                    }else {
                                        $firstEventDateStr = $this->_stats['first_event']->date_wp;
                                        echo sprintf(__('%s events since %s', 'wp-admin-audit'), $nrEventsStr, $firstEventDateStr);
                                    }?></li>
                                <?php foreach($this->_stats['general_events']->bySeverityLevel AS $sevLevel):
                                    if($sevLevel->count == 0) continue; // skip zero entries ?>
                                    <li><span class="wada-db-stat-sub-cat"><?php echo esc_html($sevLevel->name); ?></span> <span class="wada-db-stat-cr wada-db-stat-sub-cr"><?php echo esc_html($sevLevel->count); ?></span></li>
                                <?php endforeach; ?>
                            </ul>
                            <!--
                            <h3><?php _e('Notifications', 'wp-admin-audit'); ?></h3>
                            <ul>
                                <li>#4354354 notifications (since Aug 12th, 2020)</li>
                                <li>#3 notifications (last 24 hours)</li>
                                <li>#2 emails, #1 SMS sent</li>
                            </ul>
                            -->
                            <h3><?php _e('Sensors', 'wp-admin-audit'); ?></h3>
                            <ul>
                                <li><?php echo sprintf(__('%d total', 'wp-admin-audit'), $this->_stats['general_sensors']->totalSensors); ?> (<?php echo sprintf(__('%d active', 'wp-admin-audit'), $this->_stats['general_sensors']->bySensorStatus->active); ?>)</li>
                                <!--<li>#2 notification channels setup</li>-->
                            </ul>
                        </div>
                        <div class="wada-welcome-panel-column">
                            <h3><?php _e('Status', 'wp-admin-audit'); ?></h3>
                            <ul>
                                <li><?php
                                    $currentVersion = WADA_Version::getProductVersion();
                                    $update_plugins = get_site_transient( 'update_plugins' );
                                    //WADA_Log::debug('Dashboard update_plugins: '.print_r($update_plugins, true));

                                    $wadaSlug = 'wp-admin-audit/wp-admin-audit.php';
                                    $versionStr = sprintf(__('Version: %s', 'wp-admin-audit'), $currentVersion);
                                    $htmlPrefix = '';
                                    $versionCssClass = '';
                                    if($update_plugins){
                                        if(property_exists($update_plugins, 'response')
                                            && array_key_exists($wadaSlug, $update_plugins->response)
                                            && property_exists($update_plugins->response[$wadaSlug], 'new_version')
                                        ){
                                            $htmlPrefix = '<span class="dashicons dashicons-bell"></span>';
                                            $versionCssClass = 'wada-version-status-update-available';
                                            $versionStr .= ' ('.sprintf(
                                                    __('new version available: %s', 'wp-admin-audit'),
                                                    $update_plugins->response[$wadaSlug]->new_version)
                                                .' )';

                                        }
                                        if(property_exists($update_plugins, 'no_update')
                                            && array_key_exists($wadaSlug, $update_plugins->no_update)
                                        ){
                                            $htmlPrefix = '<span class="dashicons dashicons-yes"></span>';
                                            $versionCssClass = 'wada-version-status-current';
                                            $versionStr .= ' ('.__('latest version', 'wp-admin-audit').')';

                                        }
                                    }
                                    echo wp_kses_post($htmlPrefix.' <span class="wada-version-status '.$versionCssClass.'">'.$versionStr.'</span>'); ?>
                                </li>
                                <!--<li>License active</li>
                                <li>Data integrity</li>-->
                            </ul>
                        </div>
                        <div class="wada-welcome-panel-column wada-welcome-panel-last">
                            <img src="<?php echo ($assetsUrl.'assets/img/logo_small.png'); ?>" alt="<?php _e( 'Logo', 'wp-admin-audit' ); ?>" id="wada-main-logo"/>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    <?php
    }
}