<?php
/**
 * @copyright (C) 2021 - 2022 Holger Brandt IT Solutions
 * @license GPL2
*/

if(!defined('ABSPATH')){
    exit;
}

class WADA_View_Diagnosis extends WADA_View_BaseForm
{
    const VIEW_IDENTIFIER = 'wada-diagnosis';

    public function __construct() {
        add_action('admin_footer', array($this, 'loadJavascriptActions'));
    }

    protected function handleFormSubmissions(){
        if(isset($_POST['submit'])){
            check_admin_referer(self::VIEW_IDENTIFIER);
        }
    }

    protected function displayForm(){
        global $wpdb, $wp_version;
        $allSettings = WADA_Settings::getAllSettings(true);
    ?>
        <div class="wrap">
            <h1><?php _e('System diagnosis', 'wp-admin-audit') ?></h1>
            <form id="<?php echo self::VIEW_IDENTIFIER; ?>" method="post">
                <?php wp_nonce_field(self::VIEW_IDENTIFIER); ?>
                <input type="hidden" name="page" value="<?php echo esc_attr($this->getCurrentPage()); ?>" />
                <table class="form-table wada-system-diagnosis">
                    <tbody>
                    <tr>
                        <th><?php echo WADA_Version::getProductName(); ?></th>
                        <td><?php echo WADA_Version::getProductVersion(true); ?> (DB: <?php echo WADA_Settings::getDatabaseVersion(); ?>)</td>
                    </tr>
                    <tr>
                        <th><?php _e('Site', 'wp-admin-audit'); ?></th>
                        <td><?php echo get_site_url(); ?></td>
                    </tr>
                    <tr>
                        <th><?php _e('Operating system', 'wp-admin-audit'); ?></th>
                        <td><?php echo php_uname(); ?></td>
                    </tr>
                    <tr>
                        <th><?php _e('Database version', 'wp-admin-audit'); ?></th>
                        <td><?php echo esc_html($wpdb->db_version()); ?></td>
                    </tr>
                    <tr>
                        <th><?php _e('WordPress version', 'wp-admin-audit'); ?></th>
                        <td><?php echo esc_html($wp_version); ?></td>
                    </tr>
                    <tr>
                        <th><?php _e('PHP version', 'wp-admin-audit'); ?></th>
                        <td><?php echo phpversion(); ?></td>
                    </tr>
                    <tr>
                        <th><?php _e('PHP max. execution time', 'wp-admin-audit'); ?></th>
                        <td><?php echo ini_get('max_execution_time'); ?></td>
                    </tr>
                    <tr>
                        <th><?php _e('PHP memory limit', 'wp-admin-audit'); ?></th>
                        <td><?php echo ini_get('memory_limit'); ?></td>
                    </tr>
                    <tr>
                        <th><?php echo 'PHP parse_ini_file'; ?></th>
                        <td><?php echo function_exists('parse_ini_file') ? __('OK', 'wp-admin-audit') : '<strong style="color:red">'.__('Disabled', 'wp-admin-audit').'</strong>'; ?></td>
                    </tr>
                    <tr>
                        <th><?php _e('PHP disabled functions', 'wp-admin-audit'); ?></th>
                        <td><?php
                            $disabledFunctions = ini_get('disable_functions');
                            if ($disabledFunctions!=''){
                                $dfArr = explode(',', $disabledFunctions);
                                sort($dfArr);
                                echo implode(', ', $dfArr);
                            }else{
                                _e('None', 'wp-admin-audit');
                            } ?>
                        </td>
                    </tr>
                    <tr>
                        <th><?php _e('Timezone', 'wp-admin-audit'); ?></th>
                        <td><?php
                            try {
                                $nowTime = new DateTime('now');
                                $timezoneTime = new DateTime('now', wp_timezone());
                                echo esc_html($timezoneTime->format('Y-m-d H:i:s') . ' ('.wp_timezone()->getName().')<br/>'.$nowTime->format('Y-m-d H:i:s') . ' (UTC)');
                            } catch (Exception $e) {
                                _e('Error', 'wp-admin-audit').': '.esc_html($e->getMessage());
                            }?>
                        </td>
                    </tr>
                    <tr>
                        <th><?php _e('Log file', 'wp-admin-audit'); ?></th>
                        <td><?php echo WADA_Log::getLogFile() .'<br/>'.WADA_FileUtils::getFileSizeOfFile(WADA_Log::getLogFile()); ?><br/><?php
                            $dwlLogNonce = wp_create_nonce('wada_dwl_log');
                            $delLogNonce = wp_create_nonce('wada_del_log');
                            $discoverInstNonce = wp_create_nonce('wada_sensor_discover_install');
                            ?>
                            <div><a href="<?php echo admin_url('admin.php?wada_download=wada.log&_wpnonce='.$dwlLogNonce); ?>" target="_blank"><?php _e( 'Download', 'wp-admin-audit' );?></a><br/></div>
                            <input type="hidden" id="wada-del-nonce" value="<?php echo $delLogNonce; ?>" />
                            <input type="hidden" id="wada-discover-install-nonce" value="<?php echo $discoverInstNonce; ?>" />
                            <div style="margin-top:10px;"><a href="#" id="deleteLog"><?php _e( 'Delete log file', 'wp-admin-audit' );?></a></div>
                        </td>
                    </tr>
                    <tr>
                        <th><?php _e('Sensors', 'wp-admin-audit'); ?></th>
                        <td><div><?php
                            $statsModel = new WADA_Model_Stats();
                            $sensorStats = $statsModel->getSensorCounts();
                            ?>
                            <table>
                                <tr>
                                    <td><?php _e('Total', 'wp-admin-audit'); ?></td>
                                    <td><?php echo $sensorStats->totalSensors; ?></td>
                                </tr>
                                <tr>
                                    <td><?php _e('Active', 'wp-admin-audit'); ?></td>
                                    <td><?php echo $sensorStats->bySensorStatus->active; ?></td>
                                </tr>
                                <tr>
                                    <td><?php _e('Inactive', 'wp-admin-audit'); ?></td>
                                    <td><?php echo $sensorStats->bySensorStatus->inactive; ?></td>
                                </tr>
                            </table><?php
                             ?>
                            </div>
                            <div style="margin-top:10px;"><a href="#" id="discoverInstallSensors"><?php _e( 'Discover & install sensors', 'wp-admin-audit' );?></a></div>
                        </td>
                    </tr>
                    <tr>
                        <th><?php _e( 'Settings', 'wp-admin-audit' ); ?></th>
                        <td>
                            <table><?php foreach($allSettings AS $key => $obj){
                                ?><tr><td><?php echo esc_html($key); ?></td><td><?php echo esc_html($obj->value); ?></td></tr><?php
                            }?>
                            </table>
                        </td>
                    </tr>
                    </tbody>
                </table>
            </form>
        </div>
    <?php
    }

    function loadJavascriptActions(){
        ?>
        <script type="text/javascript">
            (function ($) {
                $('#deleteLog').on('click', function (e) {
                    e.preventDefault();
                    let data = {};
                    jQuery.ajax({
                        url: ajaxurl,
                        data: jQuery.extend({
                            _wpnonce: jQuery('#wada-del-nonce').val(),
                            action: '_wada_ajax_delete_log'
                        }, data),
                        success: function (response) {
                            var resp = jQuery.parseJSON(response);
                            if(resp && resp.success){
                                alert(resp.msg);
                            }else{
                                console.log(response);
                                console.log(resp);
                            }
                        }
                    });
                });
                $('#discoverInstallSensors').on('click', function (e) {
                    e.preventDefault();
                    let data = {};
                    jQuery.ajax({
                        url: ajaxurl,
                        data: jQuery.extend({
                            _wpnonce: jQuery('#wada-discover-install-nonce').val(),
                            action: '_wada_ajax_discover_install_sensors'
                        }, data),
                        success: function (response) {
                            var resp = jQuery.parseJSON(response);
                            if(resp && resp.success){
                                alert(resp.msg);
                            }else{
                                console.log(response);
                                console.log(resp);
                            }
                        }
                    });
                });

            })(jQuery);
        </script>
        <?php
    }



    function deleteLogAjaxResponse(){
        WADA_Log::debug('deleteLogAjaxResponse');
        check_ajax_referer('wada_del_log');

        $logFile = WADA_Log::getLogFile();

        $res = false;
        if(unlink($logFile)){
            $msg =  __( 'Deleted log file', 'wp-admin-audit' );
            $res = true;
        }else{
            $msg = __( 'Failed to delete log file', 'wp-admin-audit' );
        }
        try{
            WADA_Log::initFile();
        }catch(RuntimeException $e){
            /// no action here
        }

        $response = array('success' => $res, 'msg' => $msg);

        die( json_encode( $response ) );
    }

    function discoverInstallSensorsAjaxResponse(){
        WADA_Log::debug('discoverInstallSensorsAjaxResponse');
        check_ajax_referer('wada_sensor_discover_install');

        require_once WP_PLUGIN_DIR.'/wp-admin-audit/classes/Setup.php';
        $wadaSetup = new WADA_Setup();
        $nrSensorsAdded = $wadaSetup->setupSensorsIfNeeded();

        if($nrSensorsAdded > 0){
            $msg = sprintf(__('%d sensors added', 'wp-admin-audit'), $nrSensorsAdded);
        }else{
            $msg = __('No sensors added', 'wp-admin-audit');
        }

        $response = array('success' => true, 'msg' => $msg);

        die( json_encode( $response ) );

    }
}