<?php
/**
 * @copyright (C) 2021 - 2022 Holger Brandt IT Solutions
 * @license GPL2
*/

if(!defined('ABSPATH')){
    exit;
}

class WADA_View_EventDetails extends WADA_View_BaseForm
{
    const VIEW_IDENTIFIER = 'wada-event-details';
    public $item = null;

    public function __construct($id = null){
        if($id){
            $model = new WADA_Model_Event($id);
            $this->item = $model->_data;
        }
    }

    protected function handleFormSubmissions(){
        if(isset($_POST['submit'])){
            check_admin_referer(self::VIEW_IDENTIFIER);
        }
    }

    protected function displayForm(){
    ?>
        <div class="wrap">
            <h1><?php _e('Event details', 'wp-admin-audit').' - '. esc_html('#'.absint($this->item->id) . ' '.$this->item->sensor_name); ?></h1>
            <form id="<?php echo self::VIEW_IDENTIFIER; ?>" method="post">
                <?php wp_nonce_field(self::VIEW_IDENTIFIER); ?>
                <input type="hidden" name="page" value="<?php echo esc_attr($this->getCurrentPage()); ?>" />

                <div id="poststuff">
                    <div id="post-body" class="metabox-holder columns-2">
                        <div id="post-body-content">
                            <div id="postbox-container-1" class="postbox-container">
                                <div id="side-sortables" class="meta-box-sortables">
                                    <div id="wada-event-details-user-info-box" class="postbox ">
                                       <h2 class=""><span><?php _e('Acting User', 'wp-admin-audit') . ' - ' . __('User Details', 'wp-admin-audit'); ?></span></h2>
                                        <div class="inside">
                                            <div id="wada-event-details-user-info-box-details">
                                                <?php if($this->item->user_id > 0): ?>
                                                    <div id="recorded-user-info">
                                                        <h4 class="title"><?php _e('User details at the time of the event', 'wp-admin-audit'); ?></h4>
                                                        <?php echo esc_html($this->item->user_name . ' <' . $this->item->user_email) . '>'; ?>
                                                    </div>
                                                    <div id="current-user-info">
                                                        <h4 class="title"><?php _e('Current user account details', 'wp-admin-audit'); ?></h4>
                                                        <?php if(!($this->item->user)): ?>
                                                        <em><?php echo sprintf(__('User account with ID %d not existing (anymore).', 'wp-admin-audit'), $this->item->user_id); ?></em>
                                                        <?php else:
                                                            $userOutline = new WADA_Layout_UserOutline($this->item->user, $this->item->user_id);
                                                            $userOutline->display();
                                                         endif; ?>
                                                    </div>
                                                <?php else: ?>
                                                    <div id="recorded-user-info">
                                                        <?php _e('User details not stored (user not logged in)', 'wp-admin-audit'); ?>
                                                    </div>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>


                            <div id="postbox-container-2" class="postbox-container">
                                <div id="" class="">
                                    <div id="wada-event-details-data wada-event-details-header" class="postbox">
                                        <div class="inside">
                                            <div class="wada-event-details-data-container">
                                                <div class="wada-event-details-data-column">
                                                    <h3><?php _e('General data', 'wp-admin-audit'); ?></h3>
                                                    <?php
                                                    $occurredOn = WADA_DateUtils::formatUTCasDatetimeForWP($this->item->occurred_on);
                                                    ?>
                                                    <div>
                                                        <table class="data">
                                                            <tbody>
                                                            <tr>
                                                                <td class="label"><?php _e('ID', 'wp-admin-audit'); ?></td>
                                                                <td class="value"><?php echo esc_html($this->item->id); ?></td>
                                                            </tr>
                                                            <?php
                                                            if(is_multisite()):
                                                                $blogDetails = get_blog_details( array( 'blog_id' => $this->item->site_id ) );
                                                            ?>
                                                                <tr>
                                                                    <td class="label"><?php _e('Site', 'wp-admin-audit'); ?></td>
                                                                    <td class="value"><?php echo esc_html($blogDetails->blogname) . '(#'.esc_html($this->item->site_id).')'; ?></td>
                                                                </tr>
                                                            <?php
                                                            endif;
                                                            ?>
                                                            <tr>
                                                                <td class="label"><?php _e('Event type', 'wp-admin-audit'); ?></td>
                                                                <td class="value"><?php echo esc_html($this->item->sensor_name); ?></td>
                                                            </tr>
                                                            <tr>
                                                                <td class="label"><?php _e('Date', 'wp-admin-audit'); ?></td>
                                                                <td class="value"><?php echo esc_html($occurredOn); ?></td>
                                                            </tr>
                                                            <tr>
                                                                <td class="label"><?php _e('IP address', 'wp-admin-audit'); ?></td>
                                                                <td class="value"><?php echo esc_html($this->item->source_ip); ?></td>
                                                            </tr>
                                                            <tr>
                                                                <td class="label"><?php _e('User agent', 'wp-admin-audit'); ?></td>
                                                                <td class="value"><?php echo esc_html($this->item->source_client); ?></td>
                                                            </tr>
                                                            </tbody>
                                                        </table>
                                                    </div>
                                                </div>
                                                <div class="wada-event-details-data-column">
                                                    <?php
                                                    if($this->item->object_id):
                                                        echo WADA_Layout_EventDetailsBase::getEventObjectDetailsTable($this->item);
                                                    endif;
                                                    ?>
                                                </div>
                                                <div class="wada-event-details-data-column">
                                                    <h3><?php _e('Integrity checks', 'wp-admin-audit'); ?></h3>

                                                    <div>
                                                        <table class="data">
                                                            <tbody>
                                                            <tr>
                                                                <td class="label"><?php _e('Header hash', 'wp-admin-audit'); ?></td>
                                                                <td class="value"><span title="<?php echo esc_html($this->item->check_value_head); ?>"><?php echo esc_html(substr($this->item->check_value_head, 0, 7)); ?></span></td>
                                                            </tr>
                                                            <tr>
                                                                <td class="label"><?php _e('Full hash', 'wp-admin-audit'); ?></td>
                                                                <td class="value"><span title="<?php echo esc_html($this->item->check_value_full); ?>"><?php echo esc_html(substr($this->item->check_value_full, 0, 7)); ?></span></td>
                                                            </tr>
                                                            <!--
                                                            <tr>
                                                                <td class="label"><?php _e('Replication', 'wp-admin-audit'); ?></td>
                                                                <td class="value"><?php echo esc_html($this->item->replication_done ? __('Done', 'wp-admin-audit') : __('Pending', 'wp-admin-audit')); ?></td>
                                                            </tr>
                                                            -->
                                                            </tbody>
                                                        </table>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="clear"></div>
                                        </div>
                                    </div>
                                    <div id="wada-event-details-data wada-event-details-infos" class="postbox ">
                                        <div class="inside">
                                            <?php WADA_Layout_EventDetailsBase::getEventDetailsLayout($this->item)->display(); ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </form>
        </div>
    <?php
    }
}