<?php
/**
 * @copyright (C) 2021 - 2022 Holger Brandt IT Solutions
 * @license GPL2
*/

if(!defined('ABSPATH')){
    exit;
}

class WADA_Layout_PostEvent extends WADA_Layout_EventDetailsBase
{
    const LAYOUT_IDENTIFIER = 'wada-layout-post-event';

    public function display($returnAsHtml = false){
        if($returnAsHtml){
            ob_start();
        }
    ?>
        <div class="<?php echo self::LAYOUT_IDENTIFIER; ?>">
            <?php
            if($this->event->object_id > 0) {
                $title = sprintf(__('Post ID %d', 'wp-admin-audit'), $this->event->object_id);
            }else{
                $title = __('Post event', 'wp-admin-audit');
            }
            $subtitle = '';
            $transitionInfo = $this->extractEventInfoFromArray($this->event->infos, 'POST_STATUS_TRANSITION');
            if($transitionInfo){
                $subtitle = sprintf(__('Status changed from <em>%s</em> to <em>%s</em>', 'wp-admin-audit'), $transitionInfo->prior_value, $transitionInfo->info_value);
            }

            $postType = $this->extractValueFromInfoArray($this->event->infos, 'post_type');
            switch($postType){
                case 'post':
                    $postTypeName = __('Post', 'wp-admin-audit');
                    break;
                case 'page':
                    $postTypeName = __('Page', 'wp-admin-audit');
                    break;
                case 'attachment':
                    $postTypeName = __('Attachment', 'wp-admin-audit');
                    break;
                default:
                    $postTypeName = __('Post', 'wp-admin-audit');
            }

            $additionalParams = array();
            switch($this->event->sensor_id){
                case WADA_Sensor_Base::EVT_POST_CREATE:
                    $title = sprintf(__('%s ID %d was created', 'wp-admin-audit'), $postTypeName, $this->event->object_id);
                    break;
                case WADA_Sensor_Base::EVT_POST_UPDATE:
                    $title = sprintf(__('%s ID %d was updated', 'wp-admin-audit'), $postTypeName, $this->event->object_id);
                    break;
                case WADA_Sensor_Base::EVT_POST_DELETE:
                    $title = sprintf(__('%s ID %d was deleted', 'wp-admin-audit'), $postTypeName, $this->event->object_id);
                    $additionalParams[] = 'ONLY_SINGLE_VALUE';
                    break;
                case WADA_Sensor_Base::EVT_POST_TRASHED:
                    $title = sprintf(__('%s ID %d was trashed', 'wp-admin-audit'), $postTypeName, $this->event->object_id);
                    break;
                case WADA_Sensor_Base::EVT_POST_PUBLISHED:
                    $title = sprintf(__('%s ID %d was published', 'wp-admin-audit'), $postTypeName, $this->event->object_id);
                    break;
                case WADA_Sensor_Base::EVT_POST_UNPUBLISHED:
                    $title = sprintf(__('%s ID %d was unpublished', 'wp-admin-audit'), $postTypeName, $this->event->object_id);
                    break;
            }

            $specialInfoKeys = array(array('info_key' => 'POST_STATUS_TRANSITION', 'callback' => array($this, 'skipLine')));

            $this->renderTitleAndDefaultEventInfos($title, $subtitle, $specialInfoKeys, $additionalParams);
            ?>
        </div>
    <?php
        if($returnAsHtml){
            $html = ob_get_contents();
            ob_end_clean();
            return $html;
        }
    }
}