<?php
/**
 * @copyright (C) 2021 - 2022 Holger Brandt IT Solutions
 * @license GPL2
*/

if(!defined('ABSPATH')){
    exit;
}

class WADA_Layout_WADAEvent extends WADA_Layout_EventDetailsBase
{
    const LAYOUT_IDENTIFIER = 'wada-layout-wada-event';


    protected function renderSettingsChangeTable(){
        $allSettingsWithNameAsKey = WADA_Settings::getAllSettings(true);
        $innerHtml = '';
        if($this->event && $this->event->infos){
            $innerHtml = '<table class="data">';
            $innerHtml .= '<tbody>';
            $innerHtml .= '<tr>';
            $innerHtml .= '<th class="label">' . esc_html(__('Setting', 'wp-admin-audit')) . '</th>';
            $innerHtml .= '<th class="label">' . esc_html(__('New value', 'wp-admin-audit')) . '</th>';
            $innerHtml .= '<th class="label">' . esc_html(__('Prior value', 'wp-admin-audit')) . '</th>';
            $innerHtml .= '</tr>';
            foreach ($this->event->infos as $info) {
                $field = $info->info_key;
                $value = $info->info_value;
                $priorValue = $info->prior_value;
                if(array_key_exists($info->info_key, $allSettingsWithNameAsKey)){
                    $setting = $allSettingsWithNameAsKey[$info->info_key];
                    $field = $setting->metaData->label;
                    if($setting->metaData->field === 'checkbox'){
                        if($value == '1'){
                            $value = 'X';
                        }
                        if($priorValue == '1'){
                            $priorValue = 'X';
                        }
                    }else if($setting->metaData->field === 'select'){
                        if(array_key_exists($value, $setting->metaData->selectOptions)){
                            $value = $setting->metaData->selectOptions[$value];
                        }
                        if(array_key_exists($priorValue, $setting->metaData->selectOptions)){
                            $priorValue = $setting->metaData->selectOptions[$priorValue];
                        }
                    }
                }
                $innerHtml .= $this->renderDefaultEventInfosRow($field, $value, $priorValue);
            }
            $innerHtml .= '</tbody>';
            $innerHtml .= '</table>';
        }
        return $innerHtml;
    }

    public function display($returnAsHtml = false){
        if($returnAsHtml){
            ob_start();
        }
    ?>
        <div class="<?php echo self::LAYOUT_IDENTIFIER; ?>">
            <?php
            $title = '';
            $subtitle = '';

            switch($this->event->sensor_id){
                case WADA_Sensor_Base::EVT_PLG_WADA_SENSOR_UPDATE:
                    $title = sprintf(__('WP Admin Audit sensor ID %d updated', 'wp-admin-audit'), $this->event->object_id);
                    break;
                case WADA_Sensor_Base::EVT_PLG_WADA_SETTINGS_UPDATE:
                    $title = __('WP Admin Audit settings updated', 'wp-admin-audit');
                    break;
            }
            $html = '<h3>'.$title.'</h3><h4>'.$subtitle.'</h4>';
            $innerHtml = $this->renderSettingsChangeTable();

            echo wp_kses_post($html.$innerHtml);

            ?>
        </div>
    <?php
        if($returnAsHtml){
            $html = ob_get_contents();
            ob_end_clean();
            return $html;
        }
    }
}