<?php
/**
 * @copyright (C) 2021 - 2022 Holger Brandt IT Solutions
 * @license GPL2
*/

if(!defined('ABSPATH')){
    exit;
}

class WADA_View_Settings extends WADA_View_BaseForm
{
    const VIEW_IDENTIFIER = 'wada-general-settings';

    public function __construct() {
        add_action('admin_footer', array($this, 'loadJavascriptActions'));
    }

    protected function saveFormSubmission(){
        $settingsPriorSaving = WADA_Settings::getAllSettings();
        WADA_Settings::setRetentionPeriod(intval($_POST[WADA_Settings::EVENT_LOG_RETENTION_PERIOD_NUM]), sanitize_text_field($_POST[WADA_Settings::EVENT_LOG_RETENTION_PERIOD_UNIT]));
        WADA_Settings::setIsAnonymizeIPAddress(array_key_exists(WADA_Settings::ANONYMIZE_IP_ADDRESS, $_POST));
        WADA_Settings::setIsDeleteDatabaseDataOnUninstall(array_key_exists(WADA_Settings::DELETE_DB_DATA_ON_UNINSTALL, $_POST));
        WADA_Settings::setLoggingLevel(intval($_POST[WADA_Settings::LOGGING_LEVEL]));
        WADA_Settings::setLogFileSizeWarningLevel(intval($_POST[WADA_Settings::LOGGING_LOG_FILE_WARNING_SIZE_MB]));
        WADA_Settings::setIsLoggingForced(array_key_exists(WADA_Settings::LOGGING_FORCED, $_POST));
        $settingsAfterSaving = WADA_Settings::getAllSettings();
        do_action('wpadminaudit_settings_update', $settingsAfterSaving, $settingsPriorSaving);
    }

    protected function handleFormSubmissions(){
        if(isset($_POST['submit'])){
            check_admin_referer(self::VIEW_IDENTIFIER);
            $this->saveFormSubmission();
            $this->enqueueMessage(__('Settings saved', 'wp-admin-audit'), 'success');
        }
    }

    public function cleanupEventLogAjaxResponse(){
        WADA_Log::debug('cleanupEventLogAjaxResponse');
        check_ajax_referer(self::VIEW_IDENTIFIER);

        $res = WADA_Maintenance::cleanupEventLog();

        $response = array('success' => $res);

        die( json_encode( $response ) );
    }

    protected function displayForm(){
        $periodNumMeta = WADA_Settings::getMetadataForSetting(WADA_Settings::EVENT_LOG_RETENTION_PERIOD_NUM);
        $periodUnitMeta = WADA_Settings::getMetadataForSetting(WADA_Settings::EVENT_LOG_RETENTION_PERIOD_UNIT);
        $retentionPeriodNum = WADA_Settings::getRetentionPeriodNum();
        $retentionPeriodUnit = WADA_Settings::getRetentionPeriodUnit();
        $retentionPeriodInDays = WADA_Settings::getRetentionPeriodInDays();
        $maxRetention = WADA_Version::getFtSetting(WADA_Version::FT_ID_RET);
        WADA_Log::debug('num: '.$retentionPeriodNum.' unit: '.$retentionPeriodUnit.' = '.$retentionPeriodInDays.' days '.' in context of '.$maxRetention);
        $norm = false;
        $lt = ($maxRetention < 100000);
        $ltSubMonth = ($maxRetention <= 31);
        if(($retentionPeriodInDays > $maxRetention) || (($retentionPeriodInDays == 0) && $lt)){
            $norm = true;
            if($ltSubMonth){
                $retentionPeriodNum = $maxRetention;
                $retentionPeriodUnit = 'd';
            }else{
                $retentionPeriodNum = floor($maxRetention/12);
                $retentionPeriodUnit = 'm';
            }
            WADA_Log::debug('Changed to num: '.$retentionPeriodNum.' unit '.$retentionPeriodUnit);
        }
    ?>
        <div class="wrap">
            <h1><?php _e('General Settings', 'wp-admin-audit') ?></h1>
            <form id="<?php echo self::VIEW_IDENTIFIER; ?>" method="post">
                <?php wp_nonce_field(self::VIEW_IDENTIFIER); ?>
                <input type="hidden" name="page" value="<?php echo esc_attr($this->getCurrentPage()); ?>" />
                <table class="form-table">
                    <tbody>
                    <tr>
                        <th scope="row"><label><?php echo esc_html($periodNumMeta->label); echo ($lt ? ' <br/><em class="wada-greyed-out" title="'.esc_attr('You need to upgrade your WP Admin Audit product edition to get a higher or unlimited retention period', 'wp-admin-audit').'">'.sprintf(__('Maximum', 'wp-admin-audit').': '.__('%d days', 'wp-admin-audit'), intval($maxRetention)).'</em>' : ''); ?></label></th>
                        <td><fieldset><?php
                            WADA_HtmlUtils::boolToggleField('unlimited_retention', __('Keep event log indefinitely', 'wp-admin-audit'), $retentionPeriodNum == 0, ($lt ? array('input_class' => 'wada-hidden', 'label_class' => 'wada-hidden') : array()));
                            ?></fieldset><fieldset class="limited_retention"><label><?php _e('Keep events for:', 'wp-admin-audit'); ?></label><?php
                                WADA_HtmlUtils::inputField(WADA_Settings::EVENT_LOG_RETENTION_PERIOD_NUM, '', $retentionPeriodNum, array('omit_label'=>true,'id'=>('setting'.WADA_Settings::EVENT_LOG_RETENTION_PERIOD_NUM)));
                                WADA_HtmlUtils::hiddenField('setting-prior-'.WADA_Settings::EVENT_LOG_RETENTION_PERIOD_NUM, $retentionPeriodNum);
                                WADA_HtmlUtils::hiddenField('retention-days-on-file', $retentionPeriodInDays);
                                $disOpt = array_merge((($norm||$lt) ? array('y') : array()), ((($norm||$lt) && $ltSubMonth) ? array('m') : array()));
                                WADA_Log::debug('disOpt: '.print_r($disOpt, true));
                                WADA_HtmlUtils::selectField(WADA_Settings::EVENT_LOG_RETENTION_PERIOD_UNIT, '', $retentionPeriodUnit, $periodUnitMeta->selectOptions, $disOpt, false, array('omit_label'=>true,'id'=>('setting'.WADA_Settings::EVENT_LOG_RETENTION_PERIOD_UNIT)));
                                echo '<span class="hTip" title="'.esc_attr__('Determines how long the records should be kept in the event log (before they are deleted)', 'wp-admin-audit').'"><span class="dashicons dashicons-info"></span></span>';
                                echo '<div id="retentionWarning" class="notice notice-warning" style="display: none;padding:10px;">'.__('The new retention period is smaller than the previous one. If you save the settings, all events before the new retention period will be deleted', 'wp-admin-audit').'</div>';
                        ?></fieldset>
                        <?php if(isset($_GET['cleanup'])): ?><a id="cleanupEventLog" href="#"><?php _e('Cleanup event log', 'wp-admin-audit'); ?></a></td><?php endif; ?>
                    </tr>
                    <?php WADA_Settings::renderSettingField(WADA_Settings::ANONYMIZE_IP_ADDRESS); ?>
                    <?php WADA_Settings::renderSettingField(WADA_Settings::DELETE_DB_DATA_ON_UNINSTALL); ?>
                    <?php WADA_Settings::renderSettingField(WADA_Settings::LOGGING_LEVEL); ?>
                    <?php WADA_Settings::renderSettingField(WADA_Settings::LOGGING_LOG_FILE_WARNING_SIZE_MB); ?>
                    <?php WADA_Settings::renderSettingField(WADA_Settings::LOGGING_FORCED); ?>
                    </tbody>
                </table>
                <p class="submit"><input type="submit" name="submit" id="submit" class="button button-primary" value="<?php esc_attr_e('Save changes', 'wp-admin-audit'); ?>"></p>
            </form>
        </div>
    <?php
    }


    function loadJavascriptActions(){
        ?>
        <script type="text/javascript">
            (function ($) {
                function onUnlimitedRetentionToggle(){
                    let unlimitedRetentionActive = $('#unlimited_retention').prop('checked');
                    let unitInputId = '#setting<?php echo wp_json_encode(WADA_Settings::EVENT_LOG_RETENTION_PERIOD_UNIT); ?>';
                    let retentionInputId = '#setting<?php echo wp_json_encode(WADA_Settings::EVENT_LOG_RETENTION_PERIOD_NUM); ?>';
                    let priorRetentionInputId = '#setting-prior-<?php echo wp_json_encode(WADA_Settings::EVENT_LOG_RETENTION_PERIOD_NUM); ?>';
                    let retentionNum = jQuery(retentionInputId).val();
                    let priorRetentionNum = jQuery(priorRetentionInputId).val();
                    if(unlimitedRetentionActive){
                        jQuery('label[for="unlimited_retention"]').removeClass('wada-greyed-out');
                        $('.limited_retention').hide();
                        jQuery(priorRetentionInputId).val(retentionNum);
                        jQuery(retentionInputId).val(0);
                    }else{
                        if(priorRetentionNum == 0){ // come up with some reasonable defaults
                            if(jQuery(unitInputId).val() == 'd'){
                                priorRetentionNum = 30;
                            }else{
                                priorRetentionNum = 1;
                            }
                        }
                        jQuery(retentionInputId).val(priorRetentionNum);
                        $('.limited_retention').show();
                        jQuery('label[for="unlimited_retention"]').addClass('wada-greyed-out');
                    }
                }
                function onRetentionPeriodUpdate(){
                    let numInputId = '#setting<?php echo wp_json_encode(WADA_Settings::EVENT_LOG_RETENTION_PERIOD_NUM); ?>';
                    let unitInputId = '#setting<?php echo wp_json_encode(WADA_Settings::EVENT_LOG_RETENTION_PERIOD_UNIT); ?>';
                    let retentionNum = jQuery(numInputId).val();
                    let retentionPeriodUnit = jQuery(unitInputId).val();
                    let newRetentionInDays = getRetentionDays(retentionNum, retentionPeriodUnit);
                    let retentionDaysOnFile = parseInt(jQuery('#retention-days-on-file').val());
                    console.log('new period: '+newRetentionInDays);
                    console.log('on file is: '+retentionDaysOnFile);
                    let isPeriodShortened = false;
                    if(retentionDaysOnFile != newRetentionInDays){
                        if(retentionDaysOnFile == 0){ // prev. unlimited, now limited
                            isPeriodShortened = true;
                        }
                        if(newRetentionInDays > 0 && newRetentionInDays < retentionDaysOnFile){ // new period smaller than previous
                            isPeriodShortened = true;
                        }
                    }
                    if(isPeriodShortened){
                        $('#retentionWarning').show();
                    }else{
                        $('#retentionWarning').hide();
                    }
                }
                $('#unlimited_retention').on('change', function (e) {
                    onUnlimitedRetentionToggle();
                    onRetentionPeriodUpdate();
                });
                $('#setting<?php echo wp_json_encode(WADA_Settings::EVENT_LOG_RETENTION_PERIOD_NUM); ?>').on('change', function (e) {
                    onRetentionPeriodUpdate();
                });
                $('#setting<?php echo wp_json_encode(WADA_Settings::EVENT_LOG_RETENTION_PERIOD_UNIT); ?>').on('change', function (e) {
                    onRetentionPeriodUpdate();
                });
                $('#cleanupEventLog').on('click', function (e) {
                    e.preventDefault();
                    let data = {};
                    jQuery.ajax({
                            url: ajaxurl,
                            data: jQuery.extend({
                            _wpnonce: jQuery('#_wpnonce').val(),
                            action: '_wada_ajax_cleanup_event_log'
                    }, data),
                        success: function (response) {
                            var resp = jQuery.parseJSON(response);
                            if(resp && resp.success){
                                console.log(data);
                            }else{
                                console.log(response);
                                console.log(resp);
                            }
                        }
                    });
                });

                function getRetentionDays(retentionNum, retentionPeriodUnit){
                    retentionNum = Math.abs(parseInt(retentionNum));
                    let res = 0;
                    switch(retentionPeriodUnit){
                        case 'd':
                            res = retentionNum;
                            break;
                        case 'm':
                            res = retentionNum*31;
                            break;
                        case 'y':
                            res = retentionNum*365;
                            break;
                        default:
                            res = retentionNum;
                    }
                    return res;
                }

                onUnlimitedRetentionToggle(); // for init
            })(jQuery);
        </script>
        <?php
    }

}